aboutsummaryrefslogtreecommitdiff
path: root/src/addrman.h
diff options
context:
space:
mode:
authorPieter Wuille <pieter.wuille@gmail.com>2014-09-02 09:58:09 +0200
committerPieter Wuille <pieter.wuille@gmail.com>2014-09-02 09:58:09 +0200
commit3f6540ad8f9c7b45a0dd2b260a282d3adad2406f (patch)
tree046e2e1e5d88ae36286e0bb99ce530ff33b570b7 /src/addrman.h
parent47eb76597efb7dadb36dd98bc20bd80b2db9cd50 (diff)
downloadbitcoin-3f6540ad8f9c7b45a0dd2b260a282d3adad2406f.tar.xz
Rename IMPLEMENT_SERIALIZE to ADD_SERIALIZE_METHODS
Diffstat (limited to 'src/addrman.h')
-rw-r--r--src/addrman.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/addrman.h b/src/addrman.h
index 0790802b5c..90507cb458 100644
--- a/src/addrman.h
+++ b/src/addrman.h
@@ -46,7 +46,7 @@ private:
public:
- IMPLEMENT_SERIALIZE;
+ ADD_SERIALIZE_METHODS;
template <typename Stream, typename Operation>
inline void SerializationOp(Stream& s, Operation ser_action, int nType, int nVersion) {
@@ -268,7 +268,7 @@ public:
// This format is more complex, but significantly smaller (at most 1.5 MiB), and supports
// changes to the ADDRMAN_ parameters without breaking the on-disk structure.
//
// We don't use IMPLEMENT_SERIALIZE since the serialization and deserialization code has
// very little in common.
template<typename Stream>
void Serialize(Stream &s, int nType, int nVersionDummy) const
@@ -268,7 +268,7 @@ public:
// changes to the ADDRMAN_ parameters without breaking the on-disk structure.
//
- // We don't use IMPLEMENT_SERIALIZE since the serialization and deserialization code has
+ // We don't use ADD_SERIALIZE_METHODS since the serialization and deserialization code has
// very little in common.
template<typename Stream>